pub struct RefMut<'a, T> { /* private fields */ }Expand description
Exclusive reference to a component.
Implementations
Sourceimpl<'a, T> RefMut<'a, T>
impl<'a, T> RefMut<'a, T>
Sourcepub fn map<U, F: FnOnce(T) -> U>(orig: Self, f: F) -> RefMut<'a, U>
pub fn map<U, F: FnOnce(T) -> U>(orig: Self, f: F) -> RefMut<'a, U>
Makes a new RefMut, the component will not be flagged if its modified inside f.
This is an associated function that needs to be used as RefMut::map(...). A method would interfere with methods of the same name used through Deref.