pub struct InsertedOrModified<Storage>(pub Storage);Expand description
Wrapper type allowing iterating over inserted and modified flagged components.
Tuple Fields
0: StorageTrait Implementations
Sourceimpl<Storage: Clone> Clone for InsertedOrModified<Storage>
impl<Storage: Clone> Clone for InsertedOrModified<Storage>
Sourcefn clone(&self) -> InsertedOrModified<Storage>
fn clone(&self) -> InsertedOrModified<Storage>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'tmp, 'v: 'tmp, T: Component, Track: Tracking> IntoShiperator for InsertedOrModified<&'tmp View<'v, T, Track>>
impl<'tmp, 'v: 'tmp, T: Component, Track: Tracking> IntoShiperator for InsertedOrModified<&'tmp View<'v, T, Track>>
type Shiperator = InsertedOrModified<FullRawWindow<'tmp, T>>
Sourcefn into_shiperator(
self,
storage_ids: &mut ShipHashSet<StorageId>,
) -> (Self::Shiperator, usize, RawEntityIdAccess)
fn into_shiperator( self, storage_ids: &mut ShipHashSet<StorageId>, ) -> (Self::Shiperator, usize, RawEntityIdAccess)
Returns the Shiperator, its maximum length and
RawEntityIdAccess.Sourcefn can_captain() -> bool
fn can_captain() -> bool
Returns
true if the Shiperator can be a captain.Sourcefn can_sailor() -> bool
fn can_sailor() -> bool
Returns
true if the Shiperator can be a sailor.Sourceimpl<'tmp, 'v: 'tmp, T: Component, Track: Tracking> IntoShiperator for InsertedOrModified<&'tmp ViewMut<'v, T, Track>>
impl<'tmp, 'v: 'tmp, T: Component, Track: Tracking> IntoShiperator for InsertedOrModified<&'tmp ViewMut<'v, T, Track>>
type Shiperator = InsertedOrModified<FullRawWindow<'tmp, T>>
Sourcefn into_shiperator(
self,
storage_ids: &mut ShipHashSet<StorageId>,
) -> (Self::Shiperator, usize, RawEntityIdAccess)
fn into_shiperator( self, storage_ids: &mut ShipHashSet<StorageId>, ) -> (Self::Shiperator, usize, RawEntityIdAccess)
Returns the Shiperator, its maximum length and
RawEntityIdAccess.Sourcefn can_captain() -> bool
fn can_captain() -> bool
Returns
true if the Shiperator can be a captain.Sourcefn can_sailor() -> bool
fn can_sailor() -> bool
Returns
true if the Shiperator can be a sailor.Sourceimpl<'tmp, 'v: 'tmp, T: Component, Track: Tracking> IntoShiperator for InsertedOrModified<&'tmp mut ViewMut<'v, T, Track>>
impl<'tmp, 'v: 'tmp, T: Component, Track: Tracking> IntoShiperator for InsertedOrModified<&'tmp mut ViewMut<'v, T, Track>>
type Shiperator = InsertedOrModified<FullRawWindowMut<'tmp, T, Track>>
Sourcefn into_shiperator(
self,
storage_ids: &mut ShipHashSet<StorageId>,
) -> (Self::Shiperator, usize, RawEntityIdAccess)
fn into_shiperator( self, storage_ids: &mut ShipHashSet<StorageId>, ) -> (Self::Shiperator, usize, RawEntityIdAccess)
Returns the Shiperator, its maximum length and
RawEntityIdAccess.Sourcefn can_captain() -> bool
fn can_captain() -> bool
Returns
true if the Shiperator can be a captain.Sourcefn can_sailor() -> bool
fn can_sailor() -> bool
Returns
true if the Shiperator can be a sailor.Sourceimpl<Storage> Not for InsertedOrModified<Storage>
impl<Storage> Not for InsertedOrModified<Storage>
Sourceimpl<'tmp, T: ShiperatorCaptain> ShiperatorCaptain for InsertedOrModified<T>
impl<'tmp, T: ShiperatorCaptain> ShiperatorCaptain for InsertedOrModified<T>
Sourceunsafe fn get_captain_data(&self, _index: usize) -> Self::Out
unsafe fn get_captain_data(&self, _index: usize) -> Self::Out
Returns the component at
index. Read moreSourcefn next_slice(&mut self)
fn next_slice(&mut self)
Shiperators might iterate multiple splices of
This function is called on the switch to the next slice.
EntityIds.This function is called on the switch to the next slice.
Sourcefn sail_time(&self) -> usize
fn sail_time(&self) -> usize
Approximation of how much time iterating this Shiperator will take.
This helps pick the fastest Shiperator when iterating multiple storages. Read more
This helps pick the fastest Shiperator when iterating multiple storages. Read more
Sourcefn is_exact_sized(&self) -> bool
fn is_exact_sized(&self) -> bool
true when this Shiperator cannot return None.Sourceimpl<T: ShiperatorOutput> ShiperatorOutput for InsertedOrModified<T>
impl<T: ShiperatorOutput> ShiperatorOutput for InsertedOrModified<T>
Sourcetype Out = <T as ShiperatorOutput>::Out
type Out = <T as ShiperatorOutput>::Out
The type returned by the Shiperator.
Sourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindow<'tmp, T>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindow<'tmp, T>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, All>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, All>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, Deletion>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, Deletion>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, DeletionAndRemoval>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, DeletionAndRemoval>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, Insertion>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, Insertion>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndDeletion>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndDeletion>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndDeletionAndRemoval>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndDeletionAndRemoval>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndModification>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndModification>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndModificationAndDeletion>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndModificationAndDeletion>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndModificationAndRemoval>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndModificationAndRemoval>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndRemoval>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, InsertionAndRemoval>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, Modification>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, Modification>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, ModificationAndDeletion>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, ModificationAndDeletion>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, ModificationAndDeletionAndRemoval>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, ModificationAndDeletionAndRemoval>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, ModificationAndRemoval>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, ModificationAndRemoval>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, Removal>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, Removal>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreSourceimpl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, Untracked>>
impl<'tmp, T: Component> ShiperatorSailor for InsertedOrModified<FullRawWindowMut<'tmp, T, Untracked>>
Sourcetype Index = usize
type Index = usize
Type this Shiperator is indexed with.
This is often
This is often
usize or a tuple of usize for multiple storages.Sourceunsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
unsafe fn get_sailor_data(&self, index: Self::Index) -> Self::Out
Returns the component at
index. Read moreAuto Trait Implementations
impl<Storage> Freeze for InsertedOrModified<Storage>where
Storage: Freeze,
impl<Storage> RefUnwindSafe for InsertedOrModified<Storage>where
Storage: RefUnwindSafe,
impl<Storage> Send for InsertedOrModified<Storage>where
Storage: Send,
impl<Storage> Sync for InsertedOrModified<Storage>where
Storage: Sync,
impl<Storage> Unpin for InsertedOrModified<Storage>where
Storage: Unpin,
impl<Storage> UnsafeUnpin for InsertedOrModified<Storage>where
Storage: UnsafeUnpin,
impl<Storage> UnwindSafe for InsertedOrModified<Storage>where
Storage: UnwindSafe,