pub enum Borrow {
Unique,
Shared,
WrongThread,
MultipleThreads,
}Expand description
AtomicRefCell’s borrow error.
Variants
Unique
The Storage was borrowed when an exclusive borrow occurred.
The Storage was borrowed exclusively when a shared borrow occurred.
WrongThread
The Storage of a !Send component was accessed from an other thread.
MultipleThreads
The Storage of a !Sync component was accessed from multiple threads at the same time.