pub enum InvalidSystem {
AllStorages,
MultipleViews,
MultipleViewsMut,
WorkloadUsedAsSystem(&'static str),
}Expand description
Returned when trying to add an invalid system to a workload.
Variants
AllStorages
AllStorages borrowed alongside another storage.
MultipleViews
Multiple views of the same storage including an exclusive one.
MultipleViewsMut
Multiple exclusive views for the same storage.
WorkloadUsedAsSystem(&'static str)
System returning Workload