ShiperatorOutput

Trait ShiperatorOutput 

pub trait ShiperatorOutput {
    type Out;
}
Trait deciding what type a Shiperator will return when iterated.

This is often &T or &mut T.

Required Associated Types

type Out

The type returned by the Shiperator.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'tmp> ShiperatorOutput for &'tmp [EntityId]

Implementors

Source

impl<'tmp, T: Component, Track> ShiperatorOutput for Not<FullRawWindowMut<'tmp, T, Track>>

Source

impl<'tmp, T: Component, Track> ShiperatorOutput for Optional<FullRawWindowMut<'tmp, T, Track>>
where FullRawWindowMut<'tmp, T, Track>: ShiperatorOutput,

Source

type Out = Option<<FullRawWindowMut<'tmp, T, Track> as ShiperatorOutput>::Out>

Source

impl<'tmp, T: Component> ShiperatorOutput for Not<FullRawWindow<'tmp, T>>

Source

impl<'tmp, T: Component> ShiperatorOutput for Optional<FullRawWindow<'tmp, T>>

Source

impl<'tmp, T: ShiperatorOutput> ShiperatorOutput for Not<Inserted<T>>

Source

impl<'tmp, T: ShiperatorOutput> ShiperatorOutput for Not<InsertedOrModified<T>>

Source

impl<'tmp, T: ShiperatorOutput> ShiperatorOutput for Not<Modified<T>>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput, V: ShiperatorOutput, W: ShiperatorOutput, X: ShiperatorOutput, Y: ShiperatorOutput, Z: ShiperatorOutput, AA: ShiperatorOutput, BB: ShiperatorOutput, CC: ShiperatorOutput, DD: ShiperatorOutput, EE: ShiperatorOutput, FF: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, BB, CC, DD, EE, FF)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput, V: ShiperatorOutput, W: ShiperatorOutput, X: ShiperatorOutput, Y: ShiperatorOutput, Z: ShiperatorOutput, AA: ShiperatorOutput, BB: ShiperatorOutput, CC: ShiperatorOutput, DD: ShiperatorOutput, EE: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, BB, CC, DD, EE)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput, V: ShiperatorOutput, W: ShiperatorOutput, X: ShiperatorOutput, Y: ShiperatorOutput, Z: ShiperatorOutput, AA: ShiperatorOutput, BB: ShiperatorOutput, CC: ShiperatorOutput, DD: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, BB, CC, DD)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput, V: ShiperatorOutput, W: ShiperatorOutput, X: ShiperatorOutput, Y: ShiperatorOutput, Z: ShiperatorOutput, AA: ShiperatorOutput, BB: ShiperatorOutput, CC: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, BB, CC)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput, V: ShiperatorOutput, W: ShiperatorOutput, X: ShiperatorOutput, Y: ShiperatorOutput, Z: ShiperatorOutput, AA: ShiperatorOutput, BB: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, BB)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput, V: ShiperatorOutput, W: ShiperatorOutput, X: ShiperatorOutput, Y: ShiperatorOutput, Z: ShiperatorOutput, AA: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput, V: ShiperatorOutput, W: ShiperatorOutput, X: ShiperatorOutput, Y: ShiperatorOutput, Z: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput, V: ShiperatorOutput, W: ShiperatorOutput, X: ShiperatorOutput, Y: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput, V: ShiperatorOutput, W: ShiperatorOutput, X: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput, V: ShiperatorOutput, W: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput, V: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput, U: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput, T: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput, S: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput, R: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput, Q: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput, P: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput, O: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput, N: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M, N)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput, M: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L, M)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput, L: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K, L)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput, K: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J, K)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput, J: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I, J)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput, I: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H, I)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput, H: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G, H)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput, G: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F, G)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput, F: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E, F)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput, E: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D, E)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput, D: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C, D)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput, C: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B, C)>

Source

impl<A: ShiperatorOutput, B: ShiperatorOutput> ShiperatorOutput for Mixed<(A, B)>

Source

impl<A: ShiperatorOutput> ShiperatorOutput for Mixed<(A,)>

Source

type Out = (<A as ShiperatorOutput>::Out,)

Source

impl<S: ShiperatorOutput> ShiperatorOutput for Mixed<S>

Source

impl<T: ShiperatorOutput> ShiperatorOutput for Inserted<T>

Source

impl<T: ShiperatorOutput> ShiperatorOutput for InsertedOrModified<T>

Source

impl<T: ShiperatorOutput> ShiperatorOutput for Modified<T>