pub struct SystemInfo {
pub name: String,
pub borrow: Vec<TypeInfo>,
pub conflict: Option<Conflict>,
pub after: Vec<usize>,
pub after_all: Vec<BeforeAfterConstraint>,
pub before_all: Vec<BeforeAfterConstraint>,
pub unique_id: usize,
}Expand description
Contains information related to a system.
Fields
name: Stringborrow: Vec<TypeInfo>conflict: Option<Conflict>Information explaining why this system could not be part of the previous batch.
after: Vec<usize>Contains all ordering information the scheduler used to place this system
after_all: Vec<BeforeAfterConstraint>List of all after_all constraints
before_all: Vec<BeforeAfterConstraint>List of all before_all constraints
unique_id: usizeA unique identifier for this system within the workload