pub struct WorkloadInfo {
pub name: String,
pub batches_info: Vec<BatchInfo>,
}Expand description
Contains information related to a workload.
A workload is a collection of systems with parallelism calculated based on the types borrow by the systems.
Fields
name: Stringbatches_info: Vec<BatchInfo>Trait Implementations
Sourceimpl Clone for WorkloadInfo
impl Clone for WorkloadInfo
Sourcefn clone(&self) -> WorkloadInfo
fn clone(&self) -> WorkloadInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkloadInfo
impl Debug for WorkloadInfo
Sourceimpl<'de> Deserialize<'de> for WorkloadInfo
impl<'de> Deserialize<'de> for WorkloadInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkloadInfo
Sourceimpl PartialEq for WorkloadInfo
impl PartialEq for WorkloadInfo
Sourcefn eq(&self, other: &WorkloadInfo) -> bool
fn eq(&self, other: &WorkloadInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WorkloadInfo
impl Serialize for WorkloadInfo
impl StructuralPartialEq for WorkloadInfo