UniqueOrDefaultViewMut

Struct UniqueOrDefaultViewMut 

pub struct UniqueOrDefaultViewMut<'v, T: Unique + Default>(/* private fields */);
Exclusive view over a unique storage of a component with a default value.

If the component is not already present, its default value will be inserted.